# == Class: oradb::schema
#
#
define oradb::schema(    $user        = 'oracle',
                         $userBaseDir = '/home',
                         $group       = 'dba',
                         $oracleHome  = undef,
                         $dbName      = 'orcl',
)

{
  case $::kernel {
    Linux, SunOS: {
      $execPath    = "${oracleHome}/bin:/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin:"
      Exec { path  => $execPath,
        user       => $user,
        group      => $group,
        logoutput  => true,
      }
      File {
        ensure     => present,
        mode       => 0775,
        owner      => $user,
        group      => $group,
      }
    }
    default: {
      fail("Unrecognized operating system")
    }
  }
    
  exec { "init oracle schema hr":
    command      => "sqlplus /nolog <<-EOF
connect / as sysdba
-- DROP USER hr CASCADE;
ALTER PROFILE DEFAULT LIMIT PASSWORD_LIFE_TIME UNLIMITED; 
CREATE USER hr IDENTIFIED BY hr;
ALTER USER hr ACCOUNT UNLOCK;
ALTER USER hr DEFAULT TABLESPACE users QUOTA UNLIMITED ON users;
ALTER USER hr TEMPORARY TABLESPACE temp;
GRANT CREATE SESSION, CREATE VIEW, ALTER SESSION, CREATE SEQUENCE TO hr;
GRANT CREATE SYNONYM, CREATE DATABASE LINK, RESOURCE TO hr;
exit
EOF",
    environment  => ["ORACLE_HOME=${oracleHome}", "ORACLE_SID=${dbName}", "LD_LIBRARY_PATH=${oracleHome}/lib"],
    logoutput    => true,
    onlyif       => "/bin/ps -ef | grep -v grep | /bin/grep 'ora_smon_${dbName}'",
  }

}
